==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insert a new reservation"; break;
case "Nuova prenotazione a nome del signor":  	$messaggio = "New reservation for mister"; break;
case "cognome":  				$messaggio = "surname"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "Tipo di tariffa":  			$messaggio = "Fare type"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "sconto":  				$messaggio = "discount"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "se diversa dalla normale":  		$messaggio = "if different from the normal"; break;
case "n di persone":  				$messaggio = "number of people"; break;
case "Metodo per l'assegnazione dell'appartamento":	$messaggio = "Method for the apartment assignation"; break;
case "N fisso di appartamento":  		$messaggio = "Fixed apartment number"; break;
case "Lista di appartamenti":  			$messaggio = "Apartments list"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "N di piano":  				$messaggio = "Floor number"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "costo aggiuntivo finale":  		$messaggio = "Single extra cost"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "n di settimane da applicare":  		$messaggio = "n of weeks to apply"; break;
case "n di giorni da applicare":  		$messaggio = "n of days to apply"; break;
case "costo aggiuntivo percentuale":  		$messaggio = "percentage extra cost"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insert the reservation"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Non si pu inserire la prenozione senza utilizzare gli appartamenti della regola di assegnazione 1":	$messaggio = "The reservation can't be inserted without using apartments from the assignation rule 1"; break;
case " o spezzarla":  				$messaggio = " or dividing it"; break;
case "Utilizza anche gli appartamenti della regola 1":	$messaggio = "Use also apartments from rule 1"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide reservation in"; break;
case "parti":  					$messaggio = "pieces"; break;
case "senza utilizzare gli appartamenti della regola 1":	$messaggio = "without using apartments from rule 1"; break;
case "Non  stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "It has not been possible to divide to the reservation because of the number of people"; break;
case "Non  possibile inserire la prenotazione senza":	$messaggio = "It is not possible to insert the reservation without"; break;
case "dividerla":  				$messaggio = "dividing it"; break;
case "in":  					$messaggio = "in"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide the reservation in"; break;
case "Non si  potuto inserire la prenotazione a nome di":	$messaggio = "It was not possible to insert the reservation for"; break;
case "perch il database  stato modificato nel frattempo":	$messaggio = "because the database has been modified meanwhile"; break;
case "Prenotazione":  				$messaggio = "Reservation"; break;
case "settiman":  				$messaggio = "week"; break;
case "giorn":  					$messaggio = "day"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "per":  					$messaggio = "for"; break;
case "persone":  				$messaggio = "people"; break;
case "nell'appartamento":  			$messaggio = "in apartment"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "mobile":  				$messaggio = "mobile"; break;
case "Costo finale":  				$messaggio = "Single cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "Costo settimanale":  			$messaggio = "Weekly cost"; break;
case "Costo giornaliero":  			$messaggio = "Daily cost"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Costo percentuale":  			$messaggio = "percentage cost"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "resto da pagare":  			$messaggio = "rest to pay"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "inserita":  				$messaggio = "inserted"; break;
case "Modifica la prenotazione":  		$messaggio = "Modify reservation"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Sconto":  				$messaggio = "Discount"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insert a new reservation"; break;
case "Nuova prenotazione a nome del signor":  	$messaggio = "New reservation for mister"; break;
case "cognome":  				$messaggio = "surname"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "Tipo di tariffa":  			$messaggio = "Fare type"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "sconto":  				$messaggio = "discount"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "se diversa dalla normale":  		$messaggio = "if different from the normal"; break;
case "n di persone":  				$messaggio = "number of people"; break;
case "Metodo per l'assegnazione dell'appartamento":	$messaggio = "Method for the apartment assignation"; break;
case "N fisso di appartamento":  		$messaggio = "Fixed apartment number"; break;
case "Lista di appartamenti":  			$messaggio = "Apartments list"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "N di piano":  				$messaggio = "Floor number"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "costo aggiuntivo finale":  		$messaggio = "Single extra cost"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "n di settimane da applicare":  		$messaggio = "n of weeks to apply"; break;
case "n di giorni da applicare":  		$messaggio = "n of days to apply"; break;
case "costo aggiuntivo percentuale":  		$messaggio = "percentage extra cost"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insert the reservation"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Non si pu inserire la prenozione senza utilizzare gli appartamenti della regola di assegnazione 1":	$messaggio = "The reservation can't be inserted without using apartments from the assignation rule 1"; break;
case " o spezzarla":  				$messaggio = " or dividing it"; break;
case "Utilizza anche gli appartamenti della regola 1":	$messaggio = "Use also apartments from rule 1"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide reservation in"; break;
case "parti":  					$messaggio = "pieces"; break;
case "senza utilizzare gli appartamenti della regola 1":	$messaggio = "without using apartments from rule 1"; break;
case "Non  stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "It has not been possible to divide to the reservation because of the number of people"; break;
case "Non  possibile inserire la prenotazione senza":	$messaggio = "It is not possible to insert the reservation without"; break;
case "dividerla":  				$messaggio = "dividing it"; break;
case "in":  					$messaggio = "in"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide the reservation in"; break;
case "Non si  potuto inserire la prenotazione a nome di":	$messaggio = "It was not possible to insert the reservation for"; break;
case "perch il database  stato modificato nel frattempo":	$messaggio = "because the database has been modified meanwhile"; break;
case "Prenotazione":  				$messaggio = "Reservation"; break;
case "settiman":  				$messaggio = "week"; break;
case "giorn":  					$messaggio = "day"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "per":  					$messaggio = "for"; break;
case "persone":  				$messaggio = "people"; break;
case "nell'appartamento":  			$messaggio = "in apartment"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "mobile":  				$messaggio = "mobile"; break;
case "Costo finale":  				$messaggio = "Single cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "Costo settimanale":  			$messaggio = "Weekly cost"; break;
case "Costo giornaliero":  			$messaggio = "Daily cost"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Costo percentuale":  			$messaggio = "percentage cost"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "resto da pagare":  			$messaggio = "rest to pay"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "inserita":  				$messaggio = "inserted"; break;
case "Modifica la prenotazione":  		$messaggio = "Modify reservation"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Sconto":  				$messaggio = "Discount"; break;
case " necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "confermata":  				$messaggio = "confirmed"; break;
case "Confermata":  				$messaggio = "Confirmed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
